@@ -25,7 +25,12 @@ class op_flipud
   
   template<typename T1>
   inline static void apply(Mat<typename T1::elem_type>& out, const Op<T1,op_flipud>& in);
-
+  
+  template<typename eT>
+  inline static void apply_direct(Mat<eT>& out, const Mat<eT>& X);
+  
+  template<typename T1>
+  inline static void apply_proxy_noalias(Mat<typename T1::elem_type>& out, const Proxy<T1>& P);
   };
 
 
@@ -37,7 +42,12 @@ class op_fliplr
   
   template<typename T1>
   inline static void apply(Mat<typename T1::elem_type>& out, const Op<T1,op_fliplr>& in);
-
+  
+  template<typename eT>
+  inline static void apply_direct(Mat<eT>& out, const Mat<eT>& X);
+  
+  template<typename T1>
+  inline static void apply_proxy_noalias(Mat<typename T1::elem_type>& out, const Proxy<T1>& P);
   };
 
 
